# Overview
One of humanity's biggest problems is adapting to climate change's extreme effects. Simultaneously, another significant tendency in human progress is urbanization: By 2030, it is predicted that 60% of people on Earth will reside in cities. A rising number of people cluster in urban regions due to the desire for better living standards and survival methods, resulting in a significant urban population concentration. In contrast to the "conventional" urban demographic outlook, this phenomenon indicates the continuous influx of people into cities. Moreover, the accumulation of urban immigration is a measure of social development; that being said, when cities are overrun with a flood of people due to their limited capacity, a series of socioeconomic and environmental problems follow. Some people believe that the continuous increase in urban temperature is due to the continuous increase in urban population, and some believe that the increase in urban temperature is mainly due to global warming and the increase in greenhouse gases. We, therefore, find ourselves wondering what factors—urban warming or dense population—are responsible for the rise in urban temperatures.

The more we learn about the complex relationship between urban growth and climate adaptation, the more clear it is that the relationship between growing urban temperatures and population growth needs to be carefully considered. Urban areas increase the local consequences of global warming by acting as heat islands due to their dense infrastructure and high energy consumption. The elimination of natural landscapes in favor of asphalt and concrete, which absorb and reradiate solar heat more than natural environments, exacerbates this situation even more. Urban heating is further fueled by the growing urban population's simultaneous contributions to rising energy consumption, vehicle emissions, and garbage production. Next, in relation to the more extensive effects of global climate change, what is the amount to which the population-density-exacerbated urban heat island effect contributes to the overall rise in urban temperatures? It is imperative to comprehend the relative contributions of these components in order to create effective urban planning and climate adaptation strategies. 

# Research question
What is the relationship between the population density of US cities and the daily average temperature variations among them?

# Team Member
### Nathaniel Yang: 
In charge of collecting and initial analyzing data. To guarantee the accuracy and dependability of the data utilized in the project, Nathaniel will make use of his experience in data science. Also, ensure that both of the team members are doing their assigned jobs and that the project stays on track. In addition to managing scheduling and serving as the main point of contact for all project-related questions

### Seamus Chang: 
Focusing on the comprehensive examination and representation of data, Seamus will work in tandem with Nathaniel to grasp the essence of the information and create insightful graphics that facilitate the resolution of the research challenges. Moreover, to ensure the validity and reliability of the data analysis processes and results, Seamus will assume the responsibility of overseeing the data's integrity and the precision of the analytical interpretations. 

# Datasets
## *[Weather data for different cities](https://www.meteomatics.com/en/api/available-parameters/weather-parameter/temperature/#immediate_temperature)*
Format: JSON/XML [4/1/2024 update]

License: [Meteomatics AG](https://www.meteomatics.com/en/privacy-policy/) [4/1/2024 update]

Our investigation's essential data is provided by the selected dataset, which makes it easier to understand temperature differences across different locations. We will analyze the correlation between temperature measurements and population density in several locations. With the use of this highly sought-after data, temporal temperature fluctuations may be detected in addition to regional comparisons indicating climate trends. Additionally, temperature data analysis plays a critical part in lengthy climate research, assisting in the understanding of long-term climatic patterns and supporting evidence-based decision-making for policymakers, urban planners, and citizens everywhere. Numerous environmental and ecological studies also make use of it.

## *[United States Cities Database](https://simplemaps.com/data/us-cities)*
Format: CSV/XML [4/1/2024 update]

License: [Pareto Software, LLC](https://simplemaps.com/data/license) [4/1/2024 update]

The database of United States cities and towns stands as a testament to simplicity, accuracy, and currentness. Crafted meticulously from the ground up, we've sourced our information from authoritative entities like the U.S. Geological Survey and the U.S. Census Bureau, ensuring every piece of data is as reliable as it gets. As of January 30, 2024, the database is completely up-to-date, encompassing over 109,000 cities and towns across all 50 states, the District of Columbia, Puerto Rico, and the US Virgin Islands. It's not just comprehensive in scope but also rich in detail, offering a variety of useful fields such as latitude, longitude, and household income, all aggregated and cleaned from official sources.

## *[Monthly Mean Temperature Data for Major US Cities](https://www.kaggle.com/datasets/garrickhague/temp-data-of-prominent-us-cities-from-1948-to-2022)*
Format: CSV [4/1/2024 update]

License: [CC0: Public Domain](https://creativecommons.org/publicdomain/zero/1.0/) [4/1/2024 update]

This dataset contains monthly mean temperature data that was loaded into Python using xarray from the Climate Prediction Center (CPC) Global Land Surface Air Temperature Analysis. The latitude and longitude coordinates for each city in the dataset were then the only ones included in the data after it had been filtered. The 'select' method using the nearest point was used to determine the closest place to each city; however, this may not have produced temperature data that was precisely at the city location. Over the world, the data is displayed on a 0.5x0.5 degree grid.

# Timeline
- **Week 6: Team Selection**
- **Week 8: Data Acquisition**
  - *Data Collection*: Weather data will be acquired programmatically from the specified API. Population density data will be sourced from the provided URLs, with steps for data acquisition documented for reproducibility.
  - *Diverse Data Formats and Licenses*: Our datasets will span different formats (e.g., JSON from the API, CSV for census data) and licenses, adhering to data variety requirements.
- **Week 9: Data Processing (Cleaning and Integration)**
  - *Data Integration*: Utilizing Python/Pandas for data integration, we will conduct data profiling, quality assessment, cleaning, and simple analysis, ensuring an automated workflow that aligns with our research questions.
- **Week 10-11: Data Analysis and Visualization**
  - *Visualization*: The project will include insightful visualizations to represent our findings effectively.
- **Week 12-13: Documentation and Report Writing**
  - *Reproducible Package*: We aim to create a reproducible package detailing all steps from data acquisition to analysis in a well-documented and executable manner.
- **Week 14: Archiving and Final Submission**
  - *Archiving and Metadata*: The final step involves archiving the project with a persistent identifier and creating comprehensive metadata to describe our package, ensuring long-term accessibility and understanding.
