# Status Report: Weather Data Analysis Project
## Project Dataset Overview（City Weather):
The thorough analysis of weather patterns and demographic distribution is the main focus of this study. Its main objective is to compile and analyze large amounts of meteorological data from major cities worldwide using sophisticated analytical techniques. The main objective is to examine underlying weather patterns, look into how they relate to population density, and finally come up with a clear and understandable conclusion.
Nathaniel Yang and Seamus Chang work together to employ machine learning and data mining techniques to extract meaningful information from meteorological data that avoids cities. This project not only improves our understanding of the weather trends in different cities but also makes it possible to compare the results with demographic information. Moreover, it is an essential and crucial database for the study hypothesis we seek to explore.
The dataset that we are looking at covers population density and atmospheric heights, and It offers specific query formats for temperature data, which are significant metrics. We should build a comprehensive urban meteorological data archive is the goal. The goal is to conduct a thorough analysis of these records to identify unique weather patterns among different municipalities, predict the occurrence of severe weather, and investigate the relationship between extended climate changes and variations in population density.
The datasets support multiple temperature units (Celsius, Kelvin, and Fahrenheit) and provide examples of how to create time series data for temperature measurements at different altitudes for different geographic locations. These parameters are mapped for the climate of different locations, providing reliable weather data.

## Updated Timeline 
### Progress: Finished
### Week 6: Team selection
The team's assignment was finished; Nathaniel and Seamus simultaneously conducted analyses on various data sets; we collaborated to make sure the data we chose had a direct or indirect bearing on the findings of our study; and we employed statistical analysis tools and Python to extract pertinent data regarding the correlation between population density and air temperature, particularly the ways in which urbanization and climate change interact to impact the sustainability of cities. Second, after doing a second assessment of the data, Seamus made sure that our conclusions and results were expressed in an understandable manner.

### Progress: Finished 
### Week 8: Data Acquisition:
Data Collection: Weather data will be acquired programmatically from the CSV. Population density data will be sourced from the provided URLs, with steps for data acquisition documented for reproducibility. Thus, we chose the population density in the form of XML from the simple map and the “Monthly mean temperature for major cities in the United States” from Kaggle, which is in CSV format. With these two datasets, we can obtain trustworthy data support to examine our thesis, which may enable us to do research on our thesis.

Diverse Data Formats and Licenses: Our datasets will span different formats (e.g., JSON from the API, CSV for census data) and licenses, adhering to data variety requirements. For this part, we acquired all the data formats and licenses and listed them in each dataset.

### Progress: In progress
### Week 9: Data Processing (Cleaning and Integration)
Python is being used in conjunction with the Pandas package to consolidate and purify data. A preliminary analysis of the data was performed. The primary objective of this phase is to prepare the final two datasets that we selected for analysis, focusing on the relationship between population density and monthly average temperature variations among the major United States cities that we focus on. We aim to consolidate these two datasets into a unified structure, ensuring data quality and readability for exploratory and statistical analysis. 

During the cleaning process, we realized that one of the datasets, Weather API, from Meteomatics did not meet our requirements. We ended up focusing on the United States cities dataset from simplemaps and monthly mean temperature data for major US cities from Kaggle. The format of United States cities dataset from simplemaps is .xlsx file, which can be opened with Microsoft Excel. 

The first dataset we chose, the United States cities dataset from simplemaps, contains information on US cities, including city names, states, latitude and longitude coordinates, population counts, and density figures, etc. We first extracted the following columns, 'city', 'state_id', 'state_name', 'county_name', 'lat', 'lng', 'population', 'density', for our analysis focuses and sorted the dataset by density. We checked for and addressed missing values, standardized city names for consistency, and verified data types. 

The second dataset we chose to apply is the major US cities from Kaggle. This dataset includes monthly average temperatures for various US cities from 1948 to 2022. We transformed the dataset from a wide to a long format to facilitate easier merging with the population density data. We also standardized city names and checked for missing temperature data. Since it would be challenging to find the daily mean temperature for US cities, we decided to justify our research question: What is the relationship between the population density of US cities and the monthly average temperature variations among them? (initially daily average temperature).

To move forward to the data integration phase, we combined the cleaned population density and temperature datasets based on the city names, ensuring consistent naming conventions. The integrated dataset is a unified dataset with each row representing a city, including its population density, geographical coordinates, and monthly mean temperature. 

### Progress: In Progress
### Week 10-11: Data Analysis and Visualization
We have created a visualization of the population density data of several major cities. From our initial analysis of our dataset, the three cities with the highest population densities are New York, San Francisco, and Boston. The bar graph can be used in the future to compare the monthly average temperature of various cities, enabling us to observe more clearly whether there is a relationship between population density and the average city temperature.

### Progress: In progress
### Week 12-13: Documentation and Report Writing
The documentation and report writing for our project have not advanced as far as they should have during the last two weeks. Our original project timeline was not followed because of this unanticipated delay. As of right now, things regarding the documentation and report-writing phase haven't gone as planned. That being said, the preliminary data collection and analysis have been completed, providing a foundation that will be incorporated into our documentation when it is prepared.

We are compiling a reproducible package enriched with comprehensive documentation outlining every necessary action for result replication, details on data acquisition, and fully annotated code and workflow scripts. Our reproducible package is designed to encapsulate our project’s methodology, allowing for replication of our analysis. 
This package includes:
- **Documentation:** Guidelines outlining the steps required to replicate our analysis, ensuring clarity and accessibility for researchers and practitioners alike.
- **Code and Workflow Scripts:** Comprehensive collection of all coding scripts, and detailed workflow documentation using Jupyter notebooks to replicate our results. 
- **Analysis Results:** Inclusion of all outputs from our analysis, encompassing data files, visualizations, and any other relevant materials.
- **Software Dependencies:** A requirements.txt file listing all necessary software dependencies, alongside a record of specific package versions used, captured via the output of pip freeze.
- **Licenses:** Including licenses for all data and software created as part of our project, delineating usage rights and obligations to ensure ethical and lawful use of our materials.

### Progress: Not Started
### Week 14: Archiving and Final Submission
Moving forward to archiving and final submission, we prepare to ensure the longevity and accessibility of our project through comprehensive archival measures. We will submit a copy of our project through the Github repository, encompassing all datasets, Jupyter Notebook files, documentation, and analysis outputs, to the Zenodo long-term archive. We will ensure a persistent identifier, guaranteeing that our contributions are available for future researchers and practitioners. 
