# import
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd

data = pd.read_csv('results/merged_data.csv')
# print(data)

# Descriptive statistics for population density and average temperature
population_density_stats = data['density'].describe()
average_temperature_stats = data['average_temperature'].describe()

# Calculate temperature variation statistics (max - min temperature for each city)
temperature_variation = data.groupby('city')['average_temperature'].agg(['min', 'max'])
temperature_variation['variation'] = temperature_variation['max'] - temperature_variation['min']
temperature_variation_stats = temperature_variation['variation'].describe()

# For correlation analysis, we need to aggregate the average temperature for each city across all times
# Calculate the mean average temperature for each city
city_temperature_mean = data.groupby('city')['average_temperature'].mean()

# Combine the city population density and mean temperature into a single dataframe
city_data = data[['city', 'density']].drop_duplicates().set_index('city')
city_data['mean_temperature'] = city_temperature_mean

# Calculate the Pearson correlation coefficient between population density and mean temperature
correlation = city_data['density'].corr(city_data['mean_temperature'])

from scipy.stats import f_oneway

# Create bins for population density with labels
bins = [0, 1000, 3000, np.inf]  # Binning thresholds
labels = ['Low', 'Medium', 'High']
city_data['density_group'] = pd.cut(city_data['density'], bins=bins, labels=labels)

# Group the data by these density categories and calculate mean temperature for each group
grouped_temps = city_data.groupby('density_group')['mean_temperature']

# Collect the temperatures into lists for ANOVA
low_temps = grouped_temps.get_group('Low')
medium_temps = grouped_temps.get_group('Medium')
high_temps = grouped_temps.get_group('High')

anova_results = f_oneway(low_temps, medium_temps, high_temps)

# ------------ Graph Below -----------

# Correlation analysis
# Calculate the mean average temperature for each city
city_temperature_mean = data.groupby('city')['average_temperature'].mean()

# Combine the city population density and mean temperature into a single dataframe
city_data = data[['city', 'density', 'lat', 'lng']].drop_duplicates().set_index('city')
city_data['mean_temperature'] = city_temperature_mean

# # Calculate the Pearson correlation coefficient between population density and mean temperature
correlation = city_data['density'].corr(city_data['mean_temperature'])

# --------------------------------------------------------
# Scatter plot 
plt.figure(figsize=(10, 6))
plt.scatter(city_data['density'], city_data['mean_temperature'], alpha=0.5)
plt.title('Scatter Plot of Population Density vs. Mean Temperature')
plt.xlabel('Population Density (people per sq km)')
plt.ylabel('Mean Temperature (°C)')
plt.grid(True)
plt.savefig('results/scatterplt.png', format='png')

# --------------------------------------------------------
# Creating histograms 
fig, axes = plt.subplots(nrows=1, ncols=2, figsize=(14, 6))
axes[0].hist(city_data['density'], bins=30, color='skyblue', edgecolor='black')
axes[0].set_title('Histogram of Population Density')
axes[0].set_xlabel('Population Density (people per sq km)')
axes[0].set_ylabel('Frequency')

axes[1].hist(city_data['mean_temperature'], bins=30, color='salmon', edgecolor='black')
axes[1].set_title('Histogram of Mean Temperature')
axes[1].set_xlabel('Mean Temperature (°C)')
axes[1].set_ylabel('Frequency')

plt.savefig('results/histograms.png', format='png', dpi=300)

# --------------------------------------------------------
# Creating box plots 
plt.figure(figsize=(8, 6))
box_plot_data = [grouped_temps.get_group(group) for group in labels if group in grouped_temps.groups]
plt.boxplot(box_plot_data, labels=['Low', 'Medium', 'High'])
plt.title('Box Plot of Mean Temperatures by Population Density Group')
plt.ylabel('Mean Temperature (°C)')
plt.xlabel('Population Density Groups')

plt.savefig('results/boxplot.png', format='png', dpi=300)

# --------------------------------------------------------
# Create  heatmap
heatmap_data = city_data.pivot_table(values='mean_temperature', index='lat', columns='lng', aggfunc='mean')
plt.figure(figsize=(10, 8))
sns.heatmap(heatmap_data, cmap='coolwarm', annot=False)
plt.title('Heatmap of Mean Temperature by Geographic Location')
plt.xlabel('Longitude')
plt.ylabel('Latitude')
plt.savefig('results/heatmap.png', format='png', dpi=300)