# import
import pandas as pd

# --- Dataset 1: United States Cities Database ---
# Read uscities.xlsx file into dataframe
uscities_file_path = 'data/uscities.xlsx'
df_usCities = pd.read_excel(uscities_file_path)

# Data cleaning and select the columns we need
cols = ['city', 'state_id', 'state_name', 'county_name', 'lat', 'lng', 'population', 'density']
df_usCities = df_usCities[cols].sort_values('density', ascending=False)

# --- Dataset 2: Monthly Mean Temperature Data for Major US Cities ---
# Read the monthly mean temperature data for major us cities
cityTemp_file_path = 'data/US City Temp Data.csv'
df_cityTemp = pd.read_csv(cityTemp_file_path)

# --- Data integration
# normalize city name 
majorCity = df_cityTemp.columns.tolist()
majorCity = majorCity[1:]

df_usCities['city_normalized'] = df_usCities['city'].str.lower().str.replace(' ', '_')
df_majorCity = df_usCities[df_usCities['city_normalized'].isin(majorCity)]

# Check duplicated city name
duplicates = df_majorCity.groupby('city_normalized').filter(lambda x: len(x) > 1)
duplicate_city_names = duplicates['city_normalized'].unique()

# filter out multiple city with same city name but in different state, keep the one with higher population as major city
df_majorCity = df_majorCity.sort_values(by=['city_normalized', 'population'], ascending=[True, False])
df_majorCity = df_majorCity.drop_duplicates(subset='city_normalized', keep='first')
df_majorCity = df_majorCity.reset_index(drop=True)

# Reshape the temperature data to a long format
temp_long = pd.melt(df_cityTemp, id_vars=['time'], var_name='city_normalized', value_name='average_temperature')

# Convert the 'city_normalized' column to lowercase to ensure consistency with the population data
temp_long['city_normalized'] = temp_long['city_normalized'].str.lower()

# Merge the reshaped temperature data with the population density data
merged_data = pd.merge(df_majorCity, temp_long, on='city_normalized', how='inner')

# Export integrated data into csv file
output_path = 'results/merged_data.csv'
merged_data.to_csv(output_path, index=False)